==> beast-stock-api-1.6.0-20201031.063527-17-sources.jar: com/thebeastshop/stock/dto/SStockRecordConditionDTO.java <==
package com.thebeastshop.stock.dto;

import com.thebeastshop.common.BaseQueryCond;
import com.thebeastshop.stock.enums.SStockInOutTypeEnum;

import java.util.Date;

/**
 * Created by admin on 2017/1/23.
 */
public class SStockRecordConditionDTO extends BaseQueryCond {
    private Long id;
    private String commandCode;
    private Long takeStockRcdId;
    private String warehouseCode;
    private SStockInOutTypeEnum inOutType;
    private String skuCode;
    private Integer quantity;
    private String memo;
    private Long submitUserId;
    private Date submitTime;
    private Date submitTimeStart;
    private Date submitTimeEnd;
    
    public SStockRecordConditionDTO(){}
    
    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getCommandCode() {
        return commandCode;
    }

    public void setCommandCode(String commandCode) {
        this.commandCode = commandCode;
    }

    public Long getTakeStockRcdId() {
        return takeStockRcdId;
    }

    public void setTakeStockRcdId(Long takeStockRcdId) {
        this.takeStockRcdId = takeStockRcdId;
    }

    public String getWarehouseCode() {
        return warehouseCode;
    }

    public void setWarehouseCode(String warehouseCode) {
        this.warehouseCode = warehouseCode;
    }

    public SStockInOutTypeEnum getInOutType() {
        return inOutType;
    }

    public void setInOutType(SStockInOutTypeEnum inOutType) {
        this.inOutType = inOutType;
    }

    public String getSkuCode() {
        return skuCode;
    }

    public void setSkuCode(String skuCode) {
        this.skuCode = skuCode;
    }

    public Integer getQuantity() {
        return quantity;
    }

    public void setQuantity(Integer quantity) {
        this.quantity = quantity;
    }

    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }

    public Long getSubmitUserId() {
        return submitUserId;
    }

    public void setSubmitUserId(Long submitUserId) {
        this.submitUserId = submitUserId;
    }

    public Date getSubmitTime() {
        return submitTime;
    }

    public void setSubmitTime(Date submitTime) {
        this.submitTime = submitTime;
    }

    public Date getSubmitTimeStart() {
        return submitTimeStart;
    }

    public void setSubmitTimeStart(Date submitTimeStart) {
        this.submitTimeStart = submitTimeStart;
    }

    public Date getSubmitTimeEnd() {
        return submitTimeEnd;
    }

    public void setSubmitTimeEnd(Date submitTimeEnd) {
        this.submitTimeEnd = submitTimeEnd;
    }
}

==> beast-stock-api-1008316-20250724.095034-6-sources.jar: com/thebeastshop/stock/dto/SStockRecordConditionDTO.java <==
package com.thebeastshop.stock.dto;

import com.thebeastshop.common.BaseQueryCond;
import com.thebeastshop.stock.enums.SStockInOutTypeEnum;

import java.util.Date;
import java.util.List;

/**
 * Created by admin on 2017/1/23.
 */
public class SStockRecordConditionDTO extends BaseQueryCond {
    private Long id;
    private String commandCode;
    private Long takeStockRcdId;
    private String warehouseCode;
    private SStockInOutTypeEnum inOutType;
    private List<Integer> inOutTypes;
    private String skuCode;
    private Integer quantity;
    private String memo;
    private Long submitUserId;
    private Date submitTime;
    private Date submitTimeStart;
    private Date submitTimeEnd;
    
    public SStockRecordConditionDTO(){}
    
    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getCommandCode() {
        return commandCode;
    }

    public void setCommandCode(String commandCode) {
        this.commandCode = commandCode;
    }

    public Long getTakeStockRcdId() {
        return takeStockRcdId;
    }

    public void setTakeStockRcdId(Long takeStockRcdId) {
        this.takeStockRcdId = takeStockRcdId;
    }

    public String getWarehouseCode() {
        return warehouseCode;
    }

    public void setWarehouseCode(String warehouseCode) {
        this.warehouseCode = warehouseCode;
    }

    public SStockInOutTypeEnum getInOutType() {
        return inOutType;
    }

    public void setInOutType(SStockInOutTypeEnum inOutType) {
        this.inOutType = inOutType;
    }

    public String getSkuCode() {
        return skuCode;
    }

    public void setSkuCode(String skuCode) {
        this.skuCode = skuCode;
    }

    public Integer getQuantity() {
        return quantity;
    }

    public void setQuantity(Integer quantity) {
        this.quantity = quantity;
    }

    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }

    public Long getSubmitUserId() {
        return submitUserId;
    }

    public void setSubmitUserId(Long submitUserId) {
        this.submitUserId = submitUserId;
    }

    public Date getSubmitTime() {
        return submitTime;
    }

    public void setSubmitTime(Date submitTime) {
        this.submitTime = submitTime;
    }

    public Date getSubmitTimeStart() {
        return submitTimeStart;
    }

    public void setSubmitTimeStart(Date submitTimeStart) {
        this.submitTimeStart = submitTimeStart;
    }

    public Date getSubmitTimeEnd() {
        return submitTimeEnd;
    }

    public void setSubmitTimeEnd(Date submitTimeEnd) {
        this.submitTimeEnd = submitTimeEnd;
    }

    public List<Integer> getInOutTypes() {
        return inOutTypes;
    }

    public void setInOutTypes(List<Integer> inOutTypes) {
        this.inOutTypes = inOutTypes;
    }
}
